@@ -100,7 +100,7 @@ DnDWindow::~DnDWindow()
 
 void DnDWindow::on_label_drop_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context, int, int, const Gtk::SelectionData& selection_data, guint, guint time)
 {
-  const guint length = selection_data.get_length();
+  const int length = selection_data.get_length();
   const guchar* data = selection_data.get_data();
 
   if((length >= 0) && (selection_data.get_format() == 8))
@@ -134,7 +134,7 @@ void DnDWindow::on_label_popup_drag_leave(const Glib::RefPtr<Gdk::DragContext>&,
 
 void DnDWindow::on_image_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context, int, int, const Gtk::SelectionData& selection_data, guint, guint time)
 {
-  const guint length = selection_data.get_length();
+  const int length = selection_data.get_length();
   const guchar* data = selection_data.get_data();
 
   if( (length >= 0) && (selection_data.get_format() == 8) )
@@ -155,7 +155,7 @@ bool DnDWindow::on_image_drag_motion(const Glib::RefPtr<Gdk::DragContext>& conte
 
   Gtk::Widget* source_widget = Gtk::Widget::drag_get_source_widget(context);
   g_print ("motion, source %s\n", source_widget ?
-           GTK_OBJECT_TYPE_NAME (source_widget) :
+           G_OBJECT_TYPE_NAME (source_widget) :
            "NULL");
 
   typedef std::list<Glib::ustring> type_targets;
